# Python Example: Managing Static Wallets

This example shows how to manage static wallets using Python with the requests library.

## Creating a Static Wallet

```python
import requests
import json
import base64
import hashlib

# API credentials
merchant_id = 'your_merchant_id'
api_key = 'your_api_key'

# API endpoint
api_url = f'https://api.coinssend.com/v1/wallet-address'

# Wallet data
wallet_data = {
    'network': 'tron',
    'coin': 'usdt',
    'label': 'USDT Payment Address',
    'webhook_url': 'https://example.com/webhook'
}

# Generate signature
json_data = json.dumps(wallet_data)
base64_data = base64.b64encode(json_data.encode()).decode()
signature = hashlib.md5((base64_data + api_key).encode()).hexdigest()

# Set up headers
headers = {
    'Content-Type': 'application/json',
    'Merchant': merchant_id,
    'Sign': signature
}

# Make the API request
response = requests.post(api_url, headers=headers, json=wallet_data)

# Process response
if response.status_code >= 200 and response.status_code < 300:
    response_data = response.json()
    
    if response_data['status'] == 'success':
        print("Wallet address created successfully!")
        print(f"Address: {response_data['data']['address']}")
    else:
        print(f"Error: {response_data['error']['message']}")
else:
    print(f"HTTP Error: {response.status_code}")
    print(f"Response: {response.text}")
```


## Using with aiohttp (Async)

For asynchronous requests using aiohttp:

```python
import aiohttp
import asyncio
import json
import base64
import hashlib

async def create_static_wallet():
    # API credentials
    merchant_id = 'your_merchant_id'
    api_key = 'your_api_key'
    
    # Wallet data
    wallet_data = {
        'network': 'tron',
        'coin': 'usdt',
        'label': 'USDT Payment Address',
        'webhook_url': 'https://example.com/webhook'
    }
    
    # Generate signature
    json_data = json.dumps(wallet_data)
    base64_data = base64.b64encode(json_data.encode()).decode()
    signature = hashlib.md5((base64_data + api_key).encode()).hexdigest()
    
    # Set up headers
    headers = {
        'Content-Type': 'application/json',
        'Merchant': merchant_id,
        'Sign': signature
    }
    
    # Make the API request
    async with aiohttp.ClientSession() as session:
        async with session.post(
            'https://api.coinssend.com/v1/wallet-address',
            headers=headers, 
            json=wallet_data
        ) as response:
            if response.status >= 200 and response.status < 300:
                response_data = await response.json()
                
                if response_data['status'] == 'success':
                    print("Wallet address created successfully!")
                    print(f"Address: {response_data['data']['address']}")
                else:
                    print(f"Error: {response_data['error']['message']}")
            else:
                print(f"HTTP Error: {response.status}")
                print(f"Response: {await response.text()}")


# Run the event loop
asyncio.run(main())
```

## Reusable API Client Class

For multiple API calls, create a reusable client class:

```python
import requests
import json
import base64
import hashlib
from urllib.parse import urlencode

class SphereApiClient:
    def __init__(self, merchant_id, api_key, base_url='https://api.coinssend.com/v1/'):
        self.merchant_id = merchant_id
        self.api_key = api_key
        self.base_url = base_url
    
    def create_static_wallet(self, network, coin, label=None, webhook_url=None):
        data = {
            'network': network,
            'coin': coin
        }
        
        if label:
            data['label'] = label
            
        if webhook_url:
            data['webhook_url'] = webhook_url
        
        return self._send_request('POST', 'wallet-address', data)
    
    
    def _send_request(self, method, endpoint, data=None):
        url = self.base_url + endpoint
        
        headers = {
            'Content-Type': 'application/json',
            'Merchant': self.merchant_id
        }
        
        if data:
            json_data = json.dumps(data)
            base64_data = base64.b64encode(json_data.encode()).decode()
            signature = hashlib.md5((base64_data + self.api_key).encode()).hexdigest()
        else:
            # Simplified signature for GET requests
            signature = hashlib.md5(self.api_key.encode()).hexdigest()
            
        headers['Sign'] = signature
        
        if method == 'GET':
            response = requests.get(url, headers=headers)
        elif method == 'POST':
            response = requests.post(url, headers=headers, json=data)
        else:
            raise ValueError(f"Unsupported HTTP method: {method}")
        
        if response.status_code >= 200 and response.status_code < 300:
            return response.json()
        else:
            error = response.json() if response.text else {'error': {'message': 'Unknown error'}}
            raise Exception(error.get('error', {}).get('message', 'API Error'))

# Usage
try:
    client = SphereApiClient('your_merchant_id', 'your_api_key')
    
    # Create a new wallet
    create_result = client.create_static_wallet(
        network='tron',
        coin='usdt',
        label='Python USDT Wallet',
        webhook_url='https://example.com/webhook'
    )
    print(f"Wallet created: {create_result['data']['address']}")
    
        
except Exception as e:
    print(f"Error: {str(e)}")
```